@@ -1,4 +1,4 @@
-/* $Id: sip_inv.h 5109 2015-06-17 06:18:07Z nanang $ */
+/* $Id: sip_inv.h 5931 2019-01-21 08:48:02Z ming $ */
 /* 
  * Copyright (C) 2008-2011 Teluu Inc. (http://www.teluu.com)
  * Copyright (C) 2003-2008 Benny Prijono <benny@prijono.org>
@@ -96,6 +96,17 @@ typedef enum pjsip_inv_state
     PJSIP_INV_STATE_DISCONNECTED,   /**< Session is terminated.		    */
 } pjsip_inv_state;
 
+/**
+ * Structure to hold parameters when calling the callback
+ * #on_rx_offer2().
+ */
+struct pjsip_inv_on_rx_offer_cb_param
+{
+    const pjmedia_sdp_session 	*offer;	    /** Remote offer.		    */
+    const pjsip_rx_data 	*rdata;	    /** The received request.       */
+};
+
+
 /**
  * This structure contains callbacks to be registered by application to 
  * receieve notifications from the framework about various events in
@@ -154,11 +165,24 @@ typedef struct pjsip_inv_callback
      * this SDP answer will be negotiated with the offer, and the result
      * will be sent with the SIP message.
      *
+     * Note: if callback #on_rx_offer2() is implemented, this callback will
+     * not be called.
+     *
      * @param inv	The invite session.
      * @param offer	Remote offer.
      */
     void (*on_rx_offer)(pjsip_inv_session *inv,
-			const pjmedia_sdp_session *offer);
+                        const pjmedia_sdp_session *offer);
+
+    /**
+     * This callback is called when the invite session has received 
+     * new offer from peer. Variant of #on_rx_offer() callback.
+     *
+     * @param inv	The invite session.
+     * @param param	The callback parameters.
+     */
+    void (*on_rx_offer2)(pjsip_inv_session *inv,
+                         struct pjsip_inv_on_rx_offer_cb_param *param);
 
     /**
      * This callback is optional, and is called when the invite session has
@@ -235,9 +259,12 @@ typedef struct pjsip_inv_callback
      *
      * Once it has sent the ACK request, the framework will keep 
      * this ACK request in the cache. Subsequent receipt of 2xx response
-     * will not cause this callback to be called, and instead automatic
-     * retransmission of this ACK request from the cache will be done
-     * by the framework.
+     * will not cause this callback to be called (but see exception below),
+     * and instead automatic retransmission of this ACK request from
+     * the cache will be done by the framework.
+     * Exception: if app has created the ACK but has not sent it,
+     * while it receives a retransmission of 2xx response, this callback
+     * will be called again.
      *
      * This callback is optional.
      */
@@ -383,6 +410,11 @@ struct pjsip_timer;
  * Other applications that want to use these pools must understand
  * that the flip-flop pool's lifetimes are synchronized to the
  * SDP offer-answer negotiation.
+ *
+ * The lifetime of this session is controlled by the reference counter in this
+ * structure, which is manipulated by calling #pjsip_inv_add_ref and
+ * #pjsip_inv_dec_ref. When the reference counter has reached zero, then
+ * this session will be destroyed.
  */
 struct pjsip_inv_session
 {
@@ -412,6 +444,9 @@ struct pjsip_inv_session
     struct pjsip_timer	*timer;			    /**< Session Timers.    */
     pj_bool_t		 following_fork;	    /**< Internal, following
 							 forked media?	    */
+    pj_atomic_t		*ref_cnt;		    /**< Reference counter. */
+    pj_bool_t            updated_sdp_answer;        /**< SDP answer just been
+							 updated?	    */
 };
 
 
@@ -630,6 +665,30 @@ PJ_DECL(pj_status_t) pjsip_inv_create_uas(pjsip_dialog *dlg,
 					  pjsip_inv_session **p_inv);
 
 
+/**
+ * Add reference counter to the INVITE session. The reference counter controls
+ * the life time of the session, ie. when the counter reaches zero, then it 
+ * will be destroyed.
+ *
+ * @param inv       The INVITE session.
+ * @return          PJ_SUCCESS if the INVITE session reference counter
+ *                  was increased.
+ */
+PJ_DECL(pj_status_t) pjsip_inv_add_ref( pjsip_inv_session *inv );
+
+/**
+ * Decrement reference counter of the INVITE session.
+ * When the session is no longer used, it will be destroyed and
+ * caller is informed with PJ_EGONE return status.
+ *
+ * @param inv       The INVITE session.
+ * @return          PJ_SUCCESS if the INVITE session reference counter
+ *                  was decreased. A status PJ_EGONE will be returned to 
+ *                  inform that session is destroyed.
+ */
+PJ_DECL(pj_status_t) pjsip_inv_dec_ref( pjsip_inv_session *inv );
+
+
 /**
  * Forcefully terminate and destroy INVITE session, regardless of
  * the state of the session. Note that this function should only be used
