@@ -1,4 +1,4 @@
-/* $Id: siptypes.hpp 4968 2014-12-18 04:40:35Z riza $ */
+/* $Id: siptypes.hpp 6026 2019-06-12 06:00:35Z nanang $ */
 /*
  * Copyright (C) 2032 Teluu Inc. (http://www.teluu.com)
  *
@@ -104,14 +104,14 @@ public:
      *
      * @param node		Container to read values from.
      */
-    virtual void readObject(const ContainerNode &node) throw(Error);
+    virtual void readObject(const ContainerNode &node) PJSUA2_THROW(Error);
 
     /**
      * Write this object to a container node.
      *
      * @param node		Container to write values to.
      */
-    virtual void writeObject(ContainerNode &node) const throw(Error);
+    virtual void writeObject(ContainerNode &node) const PJSUA2_THROW(Error);
 };
 
 
@@ -144,6 +144,27 @@ struct TlsConfig : public PersistentObject
      */
     string		password;
 
+    /**
+     * Certificate of Authority (CA) buffer. If CaListFile, certFile or
+     * privKeyFile are set, this setting will be ignored.
+     */
+    string		CaBuf;
+
+    /**
+     * Public endpoint certificate buffer, which will be used as client-
+     * side  certificate for outgoing TLS connection, and server-side
+     * certificate for incoming TLS connection. If CaListFile, certFile or
+     * privKeyFile are set, this setting will be ignored.
+     */
+    string		certBuf;
+
+    /**
+     * Optional private key buffer of the endpoint certificate to be used. 
+     * If CaListFile, certFile or privKeyFile are set, this setting will 
+     * be ignored.
+     */
+    string		privKeyBuf;
+
     /**
      * TLS protocol method from #pjsip_ssl_method. In the future, this field
      * might be deprecated in favor of <b>proto</b> field. For now, this field 
@@ -266,14 +287,14 @@ public:
      *
      * @param node		Container to read values from.
      */
-    virtual void readObject(const ContainerNode &node) throw(Error);
+    virtual void readObject(const ContainerNode &node) PJSUA2_THROW(Error);
 
     /**
      * Write this object to a container node.
      *
      * @param node		Container to write values to.
      */
-    virtual void writeObject(ContainerNode &node) const throw(Error);
+    virtual void writeObject(ContainerNode &node) const PJSUA2_THROW(Error);
 };
 
 
@@ -363,14 +384,14 @@ public:
      *
      * @param node		Container to read values from.
      */
-    virtual void readObject(const ContainerNode &node) throw(Error);
+    virtual void readObject(const ContainerNode &node) PJSUA2_THROW(Error);
 
     /**
      * Write this object to a container node.
      *
      * @param node		Container to write values to.
      */
-    virtual void writeObject(ContainerNode &node) const throw(Error);
+    virtual void writeObject(ContainerNode &node) const PJSUA2_THROW(Error);
 };
 
 /**
@@ -404,6 +425,11 @@ struct TransportInfo
     unsigned		    usageCount;
 
 public:
+    /**
+     * Default constructor.
+     */
+    TransportInfo();
+
     /** Construct from pjsua_transport_info */
     void fromPj(const pjsua_transport_info &info);
 };
@@ -543,6 +569,8 @@ struct TsxStateEventSrc
     TimerEntry      timer;          /**< The timer.                 */
     pj_status_t     status;         /**< Transport error status.    */
     GenericData     data;           /**< Generic data.              */
+
+    TsxStateEventSrc() : status() {}
 };
 
 /**
@@ -560,6 +588,8 @@ struct TsxStateEvent
                                          *     - PJSIP_EVENT_TIMER
                                          *     - PJSIP_EVENT_USER
                                          */
+
+    TsxStateEvent();
 };
 
 /**
@@ -714,7 +744,7 @@ public:
     /**
      * Initiaize from PJSIP header.
      */
-    void fromPj(const pjsip_hdr *) throw(Error);
+    void fromPj(const pjsip_hdr *) PJSUA2_THROW(Error);
 
     /**
      * Convert to PJSIP header.
@@ -754,7 +784,7 @@ public:
     /**
      * Initiaize from PJSIP's pjsip_multipart_part.
      */
-    void fromPj(const pjsip_multipart_part &prm) throw(Error);
+    void fromPj(const pjsip_multipart_part &prm) PJSUA2_THROW(Error);
 
     /**
      * Convert to PJSIP's pjsip_multipart_part.
@@ -829,7 +859,7 @@ public:
     /**
      * Initiaize from PJSUA's pjsua_msg_data.
      */
-    void fromPj(const pjsua_msg_data &prm) throw(Error);
+    void fromPj(const pjsua_msg_data &prm) PJSUA2_THROW(Error);
 
     /**
      * Convert to PJSUA's pjsua_msg_data.
@@ -902,20 +932,20 @@ public:
 //! @cond Doxygen_Suppress
 void readIntVector( ContainerNode &node,
                     const string &array_name,
-                    IntVector &v) throw(Error);
+                    IntVector &v) PJSUA2_THROW(Error);
 void writeIntVector(ContainerNode &node,
                     const string &array_name,
-                    const IntVector &v) throw(Error);
+                    const IntVector &v) PJSUA2_THROW(Error);
 void readQosParams( ContainerNode &node,
-                    pj_qos_params &qos) throw(Error);
+                    pj_qos_params &qos) PJSUA2_THROW(Error);
 void writeQosParams( ContainerNode &node,
-                     const pj_qos_params &qos) throw(Error);
+                     const pj_qos_params &qos) PJSUA2_THROW(Error);
 void readSipHeaders( const ContainerNode &node,
                      const string &array_name,
-                     SipHeaderVector &headers) throw(Error);
+                     SipHeaderVector &headers) PJSUA2_THROW(Error);
 void writeSipHeaders(ContainerNode &node,
                      const string &array_name,
-                     const SipHeaderVector &headers) throw(Error);
+                     const SipHeaderVector &headers) PJSUA2_THROW(Error);
 //! @endcond
 #endif // SWIG
 
